@@ -4,20 +4,20 @@
 
    http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
 
-   (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
-  
-   This is free software; you can redistribute it and/or modify
+   Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+   
+   PyTango is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-  
-   This software is distributed in the hope that it will be useful,
+   
+   PyTango is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.
   
    You should have received a copy of the GNU Lesser General Public License
-   along with this program; if not, see <http://www.gnu.org/licenses/>.
+   along with PyTango.  If not, see <http://www.gnu.org/licenses/>.
    
 *******************************************************************************/
 
@@ -28,12 +28,7 @@ using namespace boost::python;
 
 void export_periodic_event_info()
 {
-    class_<Tango::PeriodicEventInfo>("PeriodicEventInfo",
-        "A structure containing available periodic event information for an attribute\n"
-        "with the folowing members,\n"
-        " - period : string\n"
-        " - extensions : vector of strings\n"
-        )
+    class_<Tango::PeriodicEventInfo>("PeriodicEventInfo")
         .def_readwrite("period", &Tango::PeriodicEventInfo::period)
         .def_readwrite("extensions", &Tango::PeriodicEventInfo::extensions)
     ;
