@@ -1,3 +1,26 @@
+/*******************************************************************************
+
+   This file is part of PyTango, a python binding for Tango
+
+   http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
+
+   Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+   
+   PyTango is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
+   PyTango is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU Lesser General Public License for more details.
+  
+   You should have received a copy of the GNU Lesser General Public License
+   along with PyTango.  If not, see <http://www.gnu.org/licenses/>.
+   
+*******************************************************************************/
+
 #ifndef _DEVICE_IMPL_H
 #define _DEVICE_IMPL_H
 
@@ -396,32 +419,4 @@ protected:
     void _init();
 };
 
-/**
- * Device_3Impl extension wrapper
- */
-class Py_Device_3ImplExt:public Tango::Device_3ImplExt
-{
-public:
-    /** pointer to pytango wrapper */
-    PyDeviceImplBase *my_dev;
-
-    /**
-     * Constructor
-     *
-     * @param[in] ptr Device_4Impl wrapper pointer
-     */
-    Py_Device_3ImplExt(PyDeviceImplBase *ptr);
-
-    /**
-     * Destructor
-     */
-    virtual ~Py_Device_3ImplExt();
-
-    /**
-     * overwrite of delete_dev method
-     */
-    virtual void delete_dev();
-
-};
-
 #endif // _DEVICE_IMPL_H
